# BED format

The BED format is a widely used format to store the genome
annotation. It's flexible and has many variation depends on how many
fields exists in the file. The official definition of BED format can
be found
[here](https://genome.ucsc.edu/FAQ/FAQformat.html#format1). Formats
like BEDPE, narrowPeak, broadPeak, or gappedPeak can be regarded as
variation of BED format.

